@@ -86,6 +86,7 @@ from jutil.format import (
     is_media_full_path,
     capfirst_lazy,
     dec0,
+    upper_lazy,
 )
 from jutil.parse import parse_datetime, parse_bool, parse_datetime_or_none
 from jutil.validators import (
@@ -771,11 +772,6 @@ class Tests(TestCase, TestSetupMixin):
         self.assertEqual(email_sanitizer("test@example.com"), "test@example.com")
         self.assertEqual(email_sanitizer("testexample.com"), "")
 
-    def test_format_dict_as_html(self):
-        a = {"b": 1, "c": {"@testVariable": "123"}}
-        res = "<pre>B: 1\nC:\n    Test variable: 123\n\n</pre>"
-        self.assertEqual(format_dict_as_html(a), res)
-
     def test_format_xml(self):
         assert settings.XMLLINT_PATH, 'add e.g. XMLLINT_PATH = "/usr/bin/xmllint" to settings.py'
         src = "<ApplicationRequest> <CustomerId>1</CustomerId>  <Command>DownloadFileList</Command><Timestamp>2019-11-27T04:32:18.613452+02:00</Timestamp><Environment>PRODUCTION</Environment></ApplicationRequest>"
@@ -943,6 +939,18 @@ class Tests(TestCase, TestSetupMixin):
             """.strip()
         self.assertEqual(out, out_ref)
 
+    def test_upper_lazy(self):
+        s = gettext_lazy(upper_lazy("missing value"))
+        s_ref = gettext_lazy("MISSING VALUE")
+        s_en = "MISSING VALUE"
+        s_fi = "PUUTTUVA ARVO"
+        with override("fi"):
+            self.assertEqual(s, s_fi)
+            self.assertEqual(s, s_ref)
+        with override("en"):
+            self.assertEqual(s, s_en)
+            self.assertEqual(s, s_ref)
+
     def test_capfirst_lazy(self):
         s = gettext_lazy(capfirst_lazy("missing value"))
         s_ref = gettext_lazy("Missing value")
